Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\supercube\__init__.py: 0%

# Coverage for C:\Users\hjanssen\HOME\pyCharmProjects\ethz_hvl\hvl_ccb\hvl_ccb\dev\supercube\__init__.py : 0%

## 4 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# Copyright (c) 2019-2020 ETH Zurich, SIS ID and HVL D-ITET

2#

3"""

4 Supercube package with implementation for system versions from 2019 on (new concept

5 with hard-PLC Siemens S7-1500 as CPU).

6"""

7

8 from .base import SupercubeConfiguration # noqa: F401

9 from .typ_a import SupercubeWithFU # noqa: F401

10 from .typ_b import SupercubeB # noqa: F401